@@ -2174,20 +2174,21 @@ static void wps_credentials(const char *key, DBusMessageIter *iter,
 
 	if (g_strcmp0(key, "Key") == 0) {
 		DBusMessageIter array;
-		unsigned char *key;
+		unsigned char *key_val;
 		int key_len;
 
 		dbus_message_iter_recurse(iter, &array);
-		dbus_message_iter_get_fixed_array(&array, &key, &key_len);
+		dbus_message_iter_get_fixed_array(&array, &key_val, &key_len);
 
 		g_free(interface->wps_cred.key);
 		interface->wps_cred.key = g_try_malloc0(
-						sizeof(char) * key_len+1);
+						sizeof(char) * key_len + 1);
 
 		if (interface->wps_cred.key == NULL)
 			return;
 
-		memcpy(interface->wps_cred.key, key, sizeof(char) * key_len);
+		memcpy(interface->wps_cred.key, key_val,
+						sizeof(char) * key_len);
 
 		SUPPLICANT_DBG("WPS key present");
 	} else if (g_strcmp0(key, "SSID") == 0) {
@@ -2321,6 +2322,7 @@ static DBusHandlerResult g_supplicant_filter(DBusConnection *conn,
 
 struct supplicant_regdom {
 	GSupplicantCountryCallback callback;
+	const char *alpha2;
 	const void *user_data;
 };
 
@@ -2328,22 +2330,21 @@ static void country_result(const char *error,
 				DBusMessageIter *iter, void *user_data)
 {
 	struct supplicant_regdom *regdom = user_data;
-	char *alpha2;
+	int result = 0;
 
 	SUPPLICANT_DBG("Country setting result");
 
 	if (user_data == NULL)
 		return;
 
-	if (error == NULL) {
-		alpha2 = (char *)regdom->user_data;
-	} else {
+	if (error != NULL) {
 		SUPPLICANT_DBG("Country setting failure %s", error);
-		alpha2 = NULL;
+		result = -EINVAL;
 	}
 
 	if (regdom->callback)
-		regdom->callback(alpha2);
+		regdom->callback(result, regdom->alpha2,
+					(void *) regdom->user_data);
 
 	g_free(regdom);
 }
@@ -2351,11 +2352,9 @@ static void country_result(const char *error,
 static void country_params(DBusMessageIter *iter, void *user_data)
 {
 	struct supplicant_regdom *regdom = user_data;
-	const char *country;
 
-	country = regdom->user_data;
-
-	dbus_message_iter_append_basic(iter, DBUS_TYPE_STRING, &country);
+	dbus_message_iter_append_basic(iter, DBUS_TYPE_STRING,
+							&regdom->alpha2);
 }
 
 int g_supplicant_set_country(const char *alpha2,
@@ -2374,6 +2373,7 @@ int g_supplicant_set_country(const char *alpha2,
 		return -ENOMEM;
 
 	regdom->callback = callback;
+	regdom->alpha2 = alpha2;
 	regdom->user_data = user_data;
 
 	return supplicant_dbus_property_set(SUPPLICANT_PATH, SUPPLICANT_INTERFACE,
@@ -2382,6 +2382,28 @@ int g_supplicant_set_country(const char *alpha2,
 						regdom);
 }
 
+int g_supplicant_interface_set_country(GSupplicantInterface *interface,
+					GSupplicantCountryCallback callback,
+							const char *alpha2,
+							void *user_data)
+{
+	struct supplicant_regdom *regdom;
+
+	regdom = dbus_malloc0(sizeof(*regdom));
+	if (regdom == NULL)
+		return -ENOMEM;
+
+	regdom->callback = callback;
+	regdom->alpha2 = alpha2;
+	regdom->user_data = user_data;
+
+	return supplicant_dbus_property_set(interface->path,
+				SUPPLICANT_INTERFACE ".Interface",
+				"Country", DBUS_TYPE_STRING_AS_STRING,
+				country_params, country_result,
+					regdom);
+}
+
 struct interface_data {
 	GSupplicantInterface *interface;
 	GSupplicantInterfaceCallback callback;
@@ -2411,6 +2433,13 @@ struct interface_scan_data {
 	void *user_data;
 };
 
+struct interface_autoscan_data {
+	GSupplicantInterface *interface;
+	GSupplicantInterfaceCallback callback;
+	const char *autoscan_params;
+	void *user_data;
+};
+
 static void interface_create_property(const char *key, DBusMessageIter *iter,
 							void *user_data)
 {
@@ -2854,6 +2883,58 @@ int g_supplicant_interface_scan(GSupplicantInterface *interface,
 	return ret;
 }
 
+static void interface_autoscan_result(const char *error,
+				DBusMessageIter *iter, void *user_data)
+{
+	struct interface_autoscan_data *data = user_data;
+	int err = 0;
+
+	if (error != NULL) {
+		SUPPLICANT_DBG("error %s", error);
+		err = -EIO;
+	}
+
+	if (data != NULL && data->callback != NULL)
+		data->callback(err, data->interface, data->user_data);
+
+	dbus_free(data);
+}
+
+static void interface_autoscan_params(DBusMessageIter *iter, void *user_data)
+{
+	struct interface_autoscan_data *data = user_data;
+
+	dbus_message_iter_append_basic(iter, DBUS_TYPE_STRING,
+						 &data->autoscan_params);
+}
+
+int g_supplicant_interface_autoscan(GSupplicantInterface *interface,
+					const char *autoscan_data,
+					GSupplicantInterfaceCallback callback,
+							void *user_data)
+{
+	struct interface_autoscan_data *data;
+	int ret;
+
+	data = dbus_malloc0(sizeof(*data));
+	if (data == NULL)
+		return -ENOMEM;
+
+	data->interface = interface;
+	data->callback = callback;
+	data->autoscan_params = autoscan_data;
+	data->user_data = user_data;
+
+	ret = supplicant_dbus_method_call(interface->path,
+			SUPPLICANT_INTERFACE ".Interface", "AutoScan",
+			interface_autoscan_params,
+			interface_autoscan_result, data);
+	if (ret < 0)
+		dbus_free(data);
+
+	return ret;
+}
+
 static int parse_supplicant_error(DBusMessageIter *iter)
 {
 	int err = -ECANCELED;
