@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2012  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -82,6 +82,7 @@ int connman_device_set_powered(struct connman_device *device,
 						connman_bool_t powered);
 int connman_device_set_scanning(struct connman_device *device,
 						connman_bool_t scanning);
+connman_bool_t connman_device_get_scanning(struct connman_device *device);
 void connman_device_reset_scanning(struct connman_device *device);
 
 int connman_device_set_disconnected(struct connman_device *device,
@@ -107,6 +108,11 @@ void connman_device_unregister(struct connman_device *device);
 void *connman_device_get_data(struct connman_device *device);
 void connman_device_set_data(struct connman_device *device, void *data);
 
+int connman_device_set_regdom(struct connman_device *device,
+						const char *alpha2);
+void connman_device_regdom_notify(struct connman_device *device,
+					int result, const char *alpha2);
+
 struct connman_device_driver {
 	const char *name;
 	enum connman_device_type type;
@@ -119,7 +125,10 @@ struct connman_device_driver {
 	int (*scan_fast) (struct connman_device *device);
 	int (*scan_hidden)(struct connman_device *device,
 			const char *ssid, unsigned int ssid_len,
-			const char *identity, const char* passphrase);
+			const char *identity, const char* passphrase,
+			void *user_data);
+	int (*set_regdom) (struct connman_device *device,
+						const char *alpha2);
 };
 
 int connman_device_driver_register(struct connman_device_driver *driver);
